@@ -1,7 +1,7 @@
 """Messaging Framework for Python"""
 from __future__ import absolute_import
 
-VERSION = (2, 5, 16)
+VERSION = (3, 0, 0)
 __version__ = '.'.join(map(str, VERSION[0:3])) + ''.join(VERSION[3:])
 __author__ = 'Ask Solem'
 __contact__ = 'ask@celeryproject.org'
@@ -13,13 +13,13 @@ __docformat__ = 'restructuredtext en'
 import os
 import sys
 
-if sys.version_info < (2, 5):  # pragma: no cover
-    if sys.version_info >= (2, 4):
+if sys.version_info < (2, 6):  # pragma: no cover
+    if sys.version_info >= (2, 5):
         raise Exception(
-            'Python 2.4 is not supported by this version. '
-            'Please use Kombu versions 1.x.')
+            'Python 2.5 is not supported by this version. '
+            'Please use Kombu versions 2.x.')
     else:
-        raise Exception('Kombu requires Python versions 2.5 or later.')
+        raise Exception('Kombu requires Python versions 2.6 or later.')
 
 STATICA_HACK = True
 globals()['kcah_acitats'[::-1].upper()] = False
@@ -54,7 +54,7 @@ all_by_module = {
 }
 
 object_origins = {}
-for module, items in all_by_module.iteritems():
+for module, items in all_by_module.items():
     for item in items:
         object_origins[item] = module
 
