@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 """
 kombu.mixins
 ============
@@ -6,7 +7,6 @@ Useful mixin classes.
 
 """
 from __future__ import absolute_import
-from __future__ import with_statement
 
 import socket
 
@@ -16,6 +16,7 @@ from itertools import count
 from time import sleep
 
 from .common import ignore_errors
+from .five import range
 from .messaging import Consumer
 from .log import get_logger
 from .utils import cached_property, nested
@@ -29,7 +30,7 @@ debug, info, warn, error = logger.debug, logger.info, logger.warn, logger.error
 
 
 class ConsumerMixin(object):
-    """Convenience mixin for implementing consumer threads.
+    """Convenience mixin for implementing consumer programs.
 
     It can be used outside of threads, with threads, or greenthreads
     (eventlet/gevent) too.
@@ -57,7 +58,7 @@ class ConsumerMixin(object):
                                  callback=[self.on_task])]
 
             def on_task(self, body, message):
-                print('Got task: %r' % (body, ))
+                print('Got task: {0!r}'.format(body))
                 message.ack()
 
     **Additional handler methods**:
@@ -81,7 +82,7 @@ class ConsumerMixin(object):
 
         * :meth:`on_connection_revived`
 
-            Handler called when the connection is re-established
+            Handler called as soon as the connection is re-established
             after connection failure.
 
             Takes no arguments.
@@ -166,7 +167,7 @@ class ConsumerMixin(object):
         while not self.should_stop:
             try:
                 if restart_limit.can_consume(_tokens):
-                    for _ in self.consume(limit=None):
+                    for _ in self.consume(limit=None):  # pragma: no cover
                         pass
                 else:
                     sleep(restart_limit.expected_time(_tokens))
@@ -179,7 +180,7 @@ class ConsumerMixin(object):
         with self.Consumer() as (connection, channel, consumers):
             with self.extra_context(connection, channel):
                 self.on_consume_ready(connection, channel, consumers, **kwargs)
-                for i in limit and xrange(limit) or count():
+                for i in limit and range(limit) or count():
                     if self.should_stop:
                         break
                     self.on_iteration()
