@@ -6,35 +6,30 @@ Redis transport.
 
 """
 from __future__ import absolute_import
-from __future__ import with_statement
 
 import socket
 
 from bisect import bisect
 from contextlib import contextmanager
 from time import time
-from Queue import Empty
 
 from anyjson import loads, dumps
 
-from kombu.exceptions import (
-    InconsistencyError,
-    StdConnectionError,
-    StdChannelError,
-    VersionMismatch,
-)
+from kombu.exceptions import InconsistencyError, VersionMismatch
+from kombu.five import Empty, values
 from kombu.log import get_logger
 from kombu.utils import cached_property, uuid
 from kombu.utils.eventio import poll, READ, ERR
+from kombu.utils.encoding import bytes_to_str
 
 NO_ROUTE_ERROR = """
-Cannot route message for exchange %r: Table empty or key no longer exists.
-Probably the key (%r) has been removed from the Redis database.
+Cannot route message for exchange {0!r}: Table empty or key no longer exists.
+Probably the key ({1!r}) has been removed from the Redis database.
 """
 
 try:
     from billiard.util import register_after_fork
-except ImportError:
+except ImportError:  # pragma: no cover
     try:
         from multiprocessing.util import register_after_fork  # noqa
     except ImportError:
@@ -43,8 +38,8 @@ except ImportError:
 
 try:
     import redis
-except ImportError:
-    redis = None  # noqa
+except ImportError:  # pragma: no cover
+    redis = None     # noqa
 
 
 from . import virtual
@@ -128,6 +123,8 @@ class QoS(virtual.QoS):
         super(QoS, self).ack(delivery_tag)
 
     def reject(self, delivery_tag, requeue=False):
+        if requeue:
+            self.restore_by_tag(delivery_tag, leftmost=True)
         self.ack(delivery_tag)
 
     @contextmanager
@@ -160,13 +157,13 @@ class QoS(virtual.QoS):
             except MutexHeld:
                 pass
 
-    def restore_by_tag(self, tag, client=None):
+    def restore_by_tag(self, tag, client=None, leftmost=False):
         with self.channel.conn_or_acquire(client) as client:
             p, _, _ = self._remove_from_indices(
                 tag, client.pipeline().hget(self.unacked_key, tag)).execute()
             if p:
                 M, EX, RK = loads(p)
-                self.channel._do_restore_message(M, EX, RK, client)
+                self.channel._do_restore_message(M, EX, RK, client, leftmost)
 
     @cached_property
     def unacked_key(self):
@@ -203,7 +200,7 @@ class MultiChannelPoller(object):
         self.poller = poll()
 
     def close(self):
-        for fd in self._chan_to_sock.itervalues():
+        for fd in values(self._chan_to_sock):
             try:
                 self.poller.unregister(fd)
             except (KeyError, ValueError):
@@ -266,7 +263,7 @@ class MultiChannelPoller(object):
                 num=channel.unacked_restore_limit,
             )
 
-    def on_poll_empty(self):
+    def maybe_restore_messages(self):
         for channel in self._channels:
             if channel.active_queues:
                 # only need to do this once, as they are not local to channel.
@@ -274,11 +271,14 @@ class MultiChannelPoller(object):
                     num=channel.unacked_restore_limit,
                 )
 
+    def on_readable(self, fileno):
+        chan, type = self._fd_to_chan[fileno]
+        if chan.qos.can_consume():
+            return chan.handlers[type]()
+
     def handle_event(self, fileno, event):
         if event & READ:
-            chan, type = self._fd_to_chan[fileno]
-            if chan.qos.can_consume():
-                return chan.handlers[type](), self
+            return self.on_readable(fileno), self
         elif event & ERR:
             chan, type = self._fd_to_chan[fileno]
             chan._poll_error(type)
@@ -299,7 +299,7 @@ class MultiChannelPoller(object):
 
         # - no new data, so try to restore messages.
         # - reset active redis commands.
-        self.on_poll_empty()
+        self.maybe_restore_messages()
 
         raise Empty()
 
@@ -379,7 +379,8 @@ class Channel(virtual.Channel):
         if self._pool is not None:
             self._pool.disconnect()
 
-    def _do_restore_message(self, payload, exchange, routing_key, client=None):
+    def _do_restore_message(self, payload, exchange, routing_key,
+                            client=None, leftmost=False):
         with self.conn_or_acquire(client) as client:
             try:
                 try:
@@ -387,12 +388,14 @@ class Channel(virtual.Channel):
                 except KeyError:
                     pass
                 for queue in self._lookup(exchange, routing_key):
-                    client.lpush(queue, dumps(payload))
+                    (client.lpush if leftmost else client.rpush)(
+                        queue, dumps(payload),
+                    )
             except Exception:
                 logger.critical('Could not restore message: %r', payload,
                                 exc_info=True)
 
-    def _restore(self, message, payload=None):
+    def _restore(self, message, leftmost=False):
         tag = message.delivery_tag
         with self.conn_or_acquire() as client:
             P, _ = client.pipeline() \
@@ -401,7 +404,10 @@ class Channel(virtual.Channel):
                 .execute()
             if P:
                 M, EX, RK = loads(P)
-                self._do_restore_message(M, EX, RK, client)
+                self._do_restore_message(M, EX, RK, client, leftmost)
+
+    def _restore_at_beginning(self, message):
+        return self._restore(message, leftmost=True)
 
     def _next_delivery_tag(self):
         return uuid()
@@ -459,9 +465,11 @@ class Channel(virtual.Channel):
             self._in_listen = False
         if response is not None:
             payload = self._handle_message(c, response)
-            if payload['type'] == 'message':
-                return (loads(payload['data']),
-                        self._fanout_to_queue[payload['channel']])
+            if bytes_to_str(payload['type']) == 'message':
+                return (
+                    loads(bytes_to_str(payload['data'])),
+                    self._fanout_to_queue[bytes_to_str(payload['channel'])],
+                )
         raise Empty()
 
     def _brpop_start(self, timeout=1):
@@ -486,9 +494,9 @@ class Channel(virtual.Channel):
                 raise Empty()
             if dest__item:
                 dest, item = dest__item
-                dest = dest.rsplit(self.sep, 1)[0]
+                dest = bytes_to_str(dest).rsplit(self.sep, 1)[0]
                 self._rotate_cycle(dest)
-                return loads(item), dest
+                return loads(bytes_to_str(item)), dest
             else:
                 raise Empty()
         finally:
@@ -577,8 +585,8 @@ class Channel(virtual.Channel):
         with self.conn_or_acquire() as client:
             values = client.smembers(key)
             if not values:
-                raise InconsistencyError(NO_ROUTE_ERROR % (exchange, key))
-            return [tuple(val.split(self.sep)) for val in values]
+                raise InconsistencyError(NO_ROUTE_ERROR.format(exchange, key))
+            return [tuple(bytes_to_str(val).split(self.sep)) for val in values]
 
     def _purge(self, queue):
         with self.conn_or_acquire() as client:
@@ -622,12 +630,20 @@ class Channel(virtual.Channel):
             except ValueError:
                 raise ValueError(
                     'Database name must be int between 0 and limit - 1')
-        return {'host': conninfo.hostname or '127.0.0.1',
-                'port': conninfo.port or DEFAULT_PORT,
-                'db': database,
-                'password': conninfo.password,
-                'max_connections': self.max_connections,
-                'socket_timeout': self.socket_timeout}
+        host = conninfo.hostname or '127.0.0.1'
+        connparams = {'host': host,
+                      'port': conninfo.port or DEFAULT_PORT,
+                      'db': database,
+                      'password': conninfo.password,
+                      'max_connections': self.max_connections,
+                      'socket_timeout': self.socket_timeout}
+        if host.split('://')[0] == 'socket':
+            connparams.update({
+                'connection_class': redis.UnixDomainSocketConnection,
+                'path': host.split('://')[1]})
+            connparams.pop('host', None)
+            connparams.pop('port', None)
+        return connparams
 
     def _create_client(self):
         return self.Client(connection_pool=self.pool)
@@ -639,7 +655,7 @@ class Channel(virtual.Channel):
         if redis.VERSION < (2, 4, 4):
             raise VersionMismatch(
                 'Redis transport requires redis-py versions 2.4.4 or later. '
-                'You have %r' % (redis.__version__, ))
+                'You have {0.__version__}'.format(redis))
 
         # KombuRedis maintains a connection attribute on it's instance and
         # uses that when executing commands
@@ -745,28 +761,27 @@ class Transport(virtual.Transport):
     def driver_version(self):
         return redis.__version__
 
-    def on_poll_init(self, poller):
-        """Called when hub starts."""
-        self.cycle.on_poll_init(poller)
-
-    def on_poll_start(self):
-        """Called by hub before each ``poll()``"""
+    def register_with_event_loop(self, connection, loop):
         cycle = self.cycle
-        cycle.on_poll_start()
-        return dict((fd, self.handle_event) for fd in cycle.fds)
+        cycle.on_poll_init(loop.poller)
+        cycle_poll_start = cycle.on_poll_start
+        add_reader = loop.add_reader
+        on_readable = self.on_readable
 
-    def on_poll_empty(self):
-        self.cycle.on_poll_empty()
+        def on_poll_start():
+            cycle_poll_start()
+            [add_reader(fd, on_readable, fd) for fd in cycle.fds]
+        loop.on_tick.add(on_poll_start)
+        loop.call_repeatedly(10, cycle.maybe_restore_messages)
 
-    def handle_event(self, fileno, event):
+    def on_readable(self, fileno):
         """Handle AIO event for one of our file descriptors."""
-        ret = self.cycle.handle_event(fileno, event)
-        if ret:
-            item, channel = ret
+        item = self.cycle.on_readable(fileno)
+        if item:
             message, queue = item
             if not queue or queue not in self._callbacks:
                 raise KeyError(
-                    "Received message for queue '%s' without consumers: %s" % (
+                    'Message for queue {0!r} without consumers: {1}'.format(
                         queue, message))
             self._callbacks[queue](message)
 
@@ -778,12 +793,14 @@ class Transport(virtual.Transport):
             DataError = exceptions.InvalidData
         else:
             DataError = exceptions.DataError
-        return ((StdConnectionError,
-                 InconsistencyError,
-                 socket.timeout,
-                 exceptions.ConnectionError,
-                 exceptions.AuthenticationError),
-                (DataError,
-                 exceptions.InvalidResponse,
-                 exceptions.ResponseError,
-                 StdChannelError))
+        return (
+            (virtual.Transport.connection_errors + (
+                InconsistencyError,
+                socket.timeout,
+                exceptions.ConnectionError,
+                exceptions.AuthenticationError)),
+            (virtual.Transport.channel_errors + (
+                DataError,
+                exceptions.InvalidResponse,
+                exceptions.ResponseError)),
+        )
