@@ -13,6 +13,8 @@ from __future__ import absolute_import
 import sys
 import traceback
 
+from kombu.five import text_t
+
 is_py3k = sys.version_info >= (3, 0)
 
 if sys.platform.startswith('java'):  # pragma: no cover
@@ -71,13 +73,13 @@ else:
 
 try:
     bytes_t = bytes
-except NameError:
+except NameError:  # pragma: no cover
     bytes_t = str  # noqa
 
 
 def safe_str(s, errors='replace'):
     s = bytes_to_str(s)
-    if not isinstance(s, basestring):
+    if not isinstance(s, (text_t, bytes)):
         return safe_repr(s, errors)
     return _safe_str(s, errors)
 
@@ -88,16 +90,16 @@ def _safe_str(s, errors='replace'):
             return s
         try:
             return str(s)
-        except Exception, exc:
-            return '<Unrepresentable %r: %r %r>' % (
+        except Exception as exc:
+            return '<Unrepresentable {0!r}: {1!r} {2!r}>'.format(
                 type(s), exc, '\n'.join(traceback.format_stack()))
     encoding = default_encoding()
     try:
         if isinstance(s, unicode):
             return s.encode(encoding, errors)
         return unicode(s, encoding, errors)
-    except Exception, exc:
-        return '<Unrepresentable %r: %r %r>' % (
+    except Exception as exc:
+        return '<Unrepresentable {0!r}: {1!r} {2!r}>'.format(
             type(s), exc, '\n'.join(traceback.format_stack()))
 
 
